==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/he.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "מסמכים",
    "Can't create document" : "לא ניתן ליצור מסמך",
    "You don't have permission to rename this document" : "אין לך הרשאות לשנות את שם המשמך",
    "Directory saved successfully." : "תיקייה נשמרה בהצלחה",
    "An error occurred while changing directory." : "שגיאה אירעה בזמן שינוי התיקייה",
    "Saved" : "נשמר",
    "Conversion failed. Check log for details." : "המרה נכשלה. יש לבדוק לוג פעילות לפרטים.",
    "Saving..." : "שמירה…",
    "Failed to load documents." : "טעינת מסמך נכשלה",
    "No documents were found. Upload or create a document to get started!" : "לא נמצאו מסמכים. יש להעלות או ליצור מסמך כדי להתחיל!",
    "No connection to server. Trying to reconnect." : "אין תקשורת לשרת. מנסה להתחבר מחדש.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "עזיבת העמוד במצב עריכה עלולה ליצור נתונים לא שמורים. מומלץ להשתמש במקום בכפתור 'סגירה'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "טעינת המסמך נכשלה. יש לבדוק אם אפשר לפתוח את המסמך בעורך חיצוני. התופעה יכולה להעיד גם על כך שבוטל השיתוף של המסמך או על כך שהמסמך נמחק לאחרונה.",
    "Save" : "שמירה",
    "Loading documents..." : "המסמך בטעינה...",
    "'.' is an invalid file name." : "'.' הנו שם לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "השם שגוי, אסור להשתמש בתווים '\\', '/', '<', '>', ':', '\"', '|', '?' ו־'*'.",
    "Align Left" : "יישור שמאלה",
    "Alignment" : "יישור",
    "Align Right" : "יישור ימינה",
    "Annotate" : "הוספת הערות",
    "Background" : "רקע",
    "Bold" : "הדגשה",
    "Bottom" : "למטה",
    "Cancel" : "ביטול",
    "Center" : "למרכז",
    "Clone" : "שכפול",
    "Clone this Style" : "העתקת סגנון",
    "Close" : "סגירה",
    "Color" : "צבע",
    "Create" : "יצירה",
    "Decrease Indent" : "הקטנת שוליים",
    "Default Style" : "סגנון ברירת מחדל",
    "Delete" : "מחיקה",
    "Family" : "משפחה",
    "Font" : "גופן",
    "Font Effects" : "אפקט גופן",
    "Format" : "עיצוב",
    "Increase Indent" : "הגדלת שוליים",
    "Insert Image" : "הוספת תמונה",
    "Invite Members" : "הזמנת חברים",
    "Italic" : "הטייה",
    "Justified" : "מיושר לשני צדדים",
    "Justify" : "יישור לשני צדדים",
    "Left" : "שמאלה",
    "Loading" : "טעינה",
    "Members" : "חברים",
    "New Name:" : "שם חדש:",
    "OK" : "אישור",
    "Open" : "פתיחה",
    "Options" : "אפשרויות",
    "Paragraph..." : "פסקה",
    "Paragraph Styles" : "סגנון פסקה",
    "Redo" : "ביצוע שוב",
    "Right" : "ימינה",
    "Size" : "גודל",
    "Spacing" : "ריווח",
    "Strikethrough" : "קו מוחק",
    "Style" : "סגנון",
    "Text" : "טקסט",
    "Top" : "עליון",
    "Underline" : "קו תחתי",
    "Undo" : "ביטול פעולה",
    "Unknown Author" : "מחבר לא ידוע",
    "Edit" : "עריכה",
    "Share" : "שיתוף",
    "guest" : "אורח",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word(דורש openOffice/libreOfficeתמיכת )",
    "Local" : "מקומי",
    "External" : "חיצוני",
    "Server URL" : "נתיב השרת",
    "Apply and test" : "ביצוע ובדיקה",
    "New document" : "מסמך חדש",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "Upload" : "העלאה",
    "Save new documents to" : "שמירת מסמך חדש אל",
    "Wrong password. Please retry." : "סיסמא שגויה. נא לנסות שוב",
    "Password" : "סיסמא"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/he.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "מסמכים",
    "Can't create document" : "לא ניתן ליצור מסמך",
    "You don't have permission to rename this document" : "אין לך הרשאות לשנות את שם המשמך",
    "Directory saved successfully." : "תיקייה נשמרה בהצלחה",
    "An error occurred while changing directory." : "שגיאה אירעה בזמן שינוי התיקייה",
    "Saved" : "נשמר",
    "Conversion failed. Check log for details." : "המרה נכשלה. יש לבדוק לוג פעילות לפרטים.",
    "Saving..." : "שמירה…",
    "Failed to load documents." : "טעינת מסמך נכשלה",
    "No documents were found. Upload or create a document to get started!" : "לא נמצאו מסמכים. יש להעלות או ליצור מסמך כדי להתחיל!",
    "No connection to server. Trying to reconnect." : "אין תקשורת לשרת. מנסה להתחבר מחדש.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "עזיבת העמוד במצב עריכה עלולה ליצור נתונים לא שמורים. מומלץ להשתמש במקום בכפתור 'סגירה'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "טעינת המסמך נכשלה. יש לבדוק אם אפשר לפתוח את המסמך בעורך חיצוני. התופעה יכולה להעיד גם על כך שבוטל השיתוף של המסמך או על כך שהמסמך נמחק לאחרונה.",
    "Save" : "שמירה",
    "Loading documents..." : "המסמך בטעינה...",
    "'.' is an invalid file name." : "'.' הנו שם לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "השם שגוי, אסור להשתמש בתווים '\\', '/', '<', '>', ':', '\"', '|', '?' ו־'*'.",
    "Align Left" : "יישור שמאלה",
    "Alignment" : "יישור",
    "Align Right" : "יישור ימינה",
    "Annotate" : "הוספת הערות",
    "Background" : "רקע",
    "Bold" : "הדגשה",
    "Bottom" : "למטה",
    "Cancel" : "ביטול",
    "Center" : "למרכז",
    "Clone" : "שכפול",
    "Clone this Style" : "העתקת סגנון",
    "Close" : "סגירה",
    "Color" : "צבע",
    "Create" : "יצירה",
    "Decrease Indent" : "הקטנת שוליים",
    "Default Style" : "סגנון ברירת מחדל",
    "Delete" : "מחיקה",
    "Family" : "משפחה",
    "Font" : "גופן",
    "Font Effects" : "אפקט גופן",
    "Format" : "עיצוב",
    "Increase Indent" : "הגדלת שוליים",
    "Insert Image" : "הוספת תמונה",
    "Invite Members" : "הזמנת חברים",
    "Italic" : "הטייה",
    "Justified" : "מיושר לשני צדדים",
    "Justify" : "יישור לשני צדדים",
    "Left" : "שמאלה",
    "Loading" : "טעינה",
    "Members" : "חברים",
    "New Name:" : "שם חדש:",
    "OK" : "אישור",
    "Open" : "פתיחה",
    "Options" : "אפשרויות",
    "Paragraph..." : "פסקה",
    "Paragraph Styles" : "סגנון פסקה",
    "Redo" : "ביצוע שוב",
    "Right" : "ימינה",
    "Size" : "גודל",
    "Spacing" : "ריווח",
    "Strikethrough" : "קו מוחק",
    "Style" : "סגנון",
    "Text" : "טקסט",
    "Top" : "עליון",
    "Underline" : "קו תחתי",
    "Undo" : "ביטול פעולה",
    "Unknown Author" : "מחבר לא ידוע",
    "Shared" : "שותף",
    "Error" : "שגיאה",
    "Error while sharing" : "שגיאה במהלך השיתוף",
    "Error while unsharing" : "שגיאה במהלך ביטול השיתוף",
    "Error while changing permissions" : "שגיאה במהלך שינוי ההגדרות",
    "Shared with you and the group {group} by {owner}" : "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
    "Shared with you by {owner}" : "שותף אתך על ידי {owner}",
    "Share" : "שיתוף",
    "Share link" : "קישור לשיתוף",
    "Password protect" : "הגנה בססמה",
    "Password" : "סיסמא",
    "Email link to person" : "שליחת קישור בדוא״ל למשתמש",
    "Send" : "שליחה",
    "Set expiration date" : "הגדרת תאריך תפוגה",
    "Expiration date" : "תאריך התפוגה",
    "group" : "קבוצה",
    "Resharing is not allowed" : "אסור לעשות שיתוף מחדש",
    "Shared in {item} with {user}" : "שותף תחת {item} עם {user}",
    "Unshare" : "הסר שיתוף",
    "can share" : "ניתן לשתף",
    "can edit" : "ניתן לערוך",
    "access control" : "בקרת גישה",
    "create" : "יצירה",
    "delete" : "מחיקה",
    "Password protected" : "מוגן בססמה",
    "Error unsetting expiration date" : "אירעה שגיאה בביטול תאריך התפוגה",
    "Error setting expiration date" : "אירעה שגיאה בעת הגדרת תאריך התפוגה",
    "Sending ..." : "מתבצעת שליחה ...",
    "Email sent" : "הודעת הדוא״ל נשלחה",
    "Warning" : "אזהרה",
    "Edit" : "עריכה",
    "guest" : "אורח",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word(דורש openOffice/libreOfficeתמיכת )",
    "Local" : "מקומי",
    "External" : "חיצוני",
    "Server URL" : "נתיב השרת",
    "Apply and test" : "ביצוע ובדיקה",
    "New document" : "מסמך חדש",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "Upload" : "העלאה",
    "Save new documents to" : "שמירת מסמך חדש אל",
    "Wrong password. Please retry." : "סיסמא שגויה. נא לנסות שוב"
},
"nplurals=2; plural=(n != 1);");
